//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/CommonWidgets/TreeViewOverlayButtons.h
//! @brief     Defines class TreeViewOverlayButtons
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_COMMONWIDGETS_TREEVIEWOVERLAYBUTTONS_H
#define BORNAGAIN_GUI_VIEWS_COMMONWIDGETS_TREEVIEWOVERLAYBUTTONS_H

#include <QObject>
#include <functional>

class QTreeView;
class QAction;

class TreeViewOverlayButtons : public QObject {
    Q_OBJECT
public:
    typedef std::function<QList<QAction*>(const QModelIndex&, bool)> FnGetActions;

    static void install(QTreeView* tree, FnGetActions fnGetActions);

protected:
    bool eventFilter(QObject* obj, QEvent* event) override;

private:
    TreeViewOverlayButtons(QObject* parent);
    void updateRecursive(const QModelIndex& index);
    void update();
    void installOverlay(const QModelIndex& index);

    FnGetActions m_getActions;
    QTreeView* m_tree;
};


#endif // BORNAGAIN_GUI_VIEWS_COMMONWIDGETS_TREEVIEWOVERLAYBUTTONS_H
